@@ -1,5 +1,17 @@
 #' @importFrom grDevices hcl
 
+print_palette_pairs <- function(i){
+  palette_list <- list(
+    gg_default = gg_color_hue(5)[c(3, 1)],
+    cbfriendly = c("#E69F00", "#56B4E9"),
+    `80s` = c("#2bd1fc", "#ff3f3f"),
+    rainbow = c("#e70000", "#ff8c00", "#ffef00", "#00811f",	"#0044ff", "#760089")[c(3, 1)],
+    mario = c("#fed1b0", "#ee1c25", "#0065b3", "#ffffff", "#894c2f")[c(1, 3)], 
+    pokemon = c("#b3ffa9", "#ffa9b3",	"#a9b3ff", "#fdff98", "#dfc189")[c(2, 3)]
+  )
+  return(palette_list[[i + 1]])
+}
+
 user_colours <- function(n, i){
   if(i == 0){
     colour_vector <- gg_color_hue(n)
